// j01.form.forms.less
/* zrt-replace: "../img" tal"string:${context/++resource++img}" */
/*---[ bootstrap forms ]------------------------------------------------------*/
/* Note: this is a customized version of the bootstrap 3 forms.less and
 * provides the form and input basics including normalize. The bootstrap 3
 * forms is included
 */
@import "b3/variables.less";
@import "b3/mixins.less";
@import "source/variables.less";
@import "source/mixins.less";
@import "b3/forms.less";
@import "source/j01.form.forms.less";
