// j01.form.btns.less
div.btns {
    width: auto;
    vertical-align: middle;
    padding: @btns-padding;
	clear: both;
    &:after {
        content: '';
        display: block;
        clear: both;
    }
    div.left {
        /* secondary (float left) */
        width: auto;
        float: left;
    }
    div.right {
        /* secondary (float right) */
        width: auto;
        float: right;
    }
    div.secondary {
        /* secondary gray (left padding) */
        width: auto;
        float: left;
        padding: @btn-secondary-padding;
    }
    div.gray {
        /* secondary gray (no padding) */
        width: auto;
        float: left;
        padding: 0;
    }
    div.btn,
    div.link {
        min-height: @btn-height;
        line-height: @btn-line-height;
        width: auto;
        cursor: pointer !important;
        margin: @btn-margin;
        padding: @btn-padding;
        float: left;
    }
    div.btn a,
    div.btn input,
    div.btn button,
    div.link a,
    div.link input,
    div.link button, {
        /* size, font, block */
        min-height: @btn-height;
        line-height: @btn-height;
        font-size: @btn-font-size;
        font-family: Verdana, Arial, Helvetica, sans-serif;
        cursor: pointer !important;
        border: none;
        display: inline-block;
        overflow: visible;
        margin: @btn-input-margin;
        padding: @btn-input-padding;
    }
    // color schema
    div.btn {
        color: @btn-color;
        background-color: @btn-bg;
        a,
        input,
        button, {
            /* render as button */
            color: @btn-color;
            background-color: @btn-bg;
            cursor: pointer !important;
            &:hover {
                text-decoration: none !important;
                color: @btn-hover-color;
                background-color: @btn-hover-bg;
            }
        }
    }
    div.gray div.btn,
    div.right div.btn,
    div.secondary div.btn, {
        color: @btn-secondary-color;
        background-color: @btn-secondary-bg;
        a,
        input,
        button {
            color: @btn-secondary-color;
            background-color: @btn-secondary-bg;
            &:hover {
                text-decoration: none !important;
                color: @btn-secondary-hover-color;
                background-color: @btn-secondary-hover-bg;
            }
        }
    }
    // render button as link
    div.link input,
    div.link button, {
        /* render as link */
        color: @btn-link-color;
        background-color: @btn-link-bg;
        border: 0;
        &:hover {
            text-decoration: none !important;
            color: @btn-link-color;
            background-color: @btn-link-hover-bg;
        }
    }
}

form div.inline div.left {
    /* widget inline padding */
    padding-left: 155px;
}

/* IE7 */
*:first-child+html form div.btns div.btn {
    padding: 0px 0px 2px 0px;
}

