// j01.form.status.less
#j01FormStatus {
    background: #009dff;
    position: fixed;
    z-index: 1031;
    top: 0;
    left: 0;
    height: 4px;
    transition: all 1s;
    width: 0;
    overflow: hidden;
}
