/* zrt-replace: "../img" tal"string:${context/++resource++img}" */
div.btns {
  width: auto;
  vertical-align: middle;
  padding: 5px 0px 5px 0px;
  clear: both;
}
div.btns:after {
  content: '';
  display: block;
  clear: both;
}
div.btns div.left {
  /* secondary (float left) */
  width: auto;
  float: left;
}
div.btns div.right {
  /* secondary (float right) */
  width: auto;
  float: right;
}
div.btns div.secondary {
  /* secondary gray (left padding) */
  width: auto;
  float: left;
  padding: 0 0 0 25px;
}
div.btns div.gray {
  /* secondary gray (no padding) */
  width: auto;
  float: left;
  padding: 0;
}
div.btns div.btn,
div.btns div.link {
  min-height: 25px;
  line-height: 25px;
  width: auto;
  cursor: pointer !important;
  margin: 0px 5px 0px 0px;
  padding: 0;
  float: left;
}
div.btns div.btn a,
div.btns div.btn input,
div.btns div.btn button,
div.btns div.link a,
div.btns div.link input,
div.btns div.link button {
  /* size, font, block */
  min-height: 25px;
  line-height: 25px;
  font-size: 14px;
  font-family: Verdana, Arial, Helvetica, sans-serif;
  cursor: pointer !important;
  border: none;
  display: inline-block;
  overflow: visible;
  margin: 0;
  padding: 0px 10px 0px 10px;
}
div.btns div.btn {
  color: #ffffff;
  background-color: #d3311f;
}
div.btns div.btn a,
div.btns div.btn input,
div.btns div.btn button {
  /* render as button */
  color: #ffffff;
  background-color: #d3311f;
  cursor: pointer !important;
}
div.btns div.btn a:hover,
div.btns div.btn input:hover,
div.btns div.btn button:hover {
  text-decoration: none !important;
  color: #ffffff;
  background-color: #d3311f;
}
div.btns div.gray div.btn,
div.btns div.right div.btn,
div.btns div.secondary div.btn {
  color: #000000;
  background-color: #cccccc;
}
div.btns div.gray div.btn a,
div.btns div.right div.btn a,
div.btns div.secondary div.btn a,
div.btns div.gray div.btn input,
div.btns div.right div.btn input,
div.btns div.secondary div.btn input,
div.btns div.gray div.btn button,
div.btns div.right div.btn button,
div.btns div.secondary div.btn button {
  color: #000000;
  background-color: #cccccc;
}
div.btns div.gray div.btn a:hover,
div.btns div.right div.btn a:hover,
div.btns div.secondary div.btn a:hover,
div.btns div.gray div.btn input:hover,
div.btns div.right div.btn input:hover,
div.btns div.secondary div.btn input:hover,
div.btns div.gray div.btn button:hover,
div.btns div.right div.btn button:hover,
div.btns div.secondary div.btn button:hover {
  text-decoration: none !important;
  color: #000000;
  background-color: #cccccc;
}
div.btns div.link input,
div.btns div.link button {
  /* render as link */
  color: #d3311f;
  background-color: #ffffff;
  border: 0;
}
div.btns div.link input:hover,
div.btns div.link button:hover {
  text-decoration: none !important;
  color: #d3311f;
  background-color: #ffffff;
}
form div.inline div.left {
  /* widget inline padding */
  padding-left: 155px;
}
/* IE7 */
*:first-child + html form div.btns div.btn {
  padding: 0px 0px 2px 0px;
}
