// variables

// colors
@orange:                    #D3311F;
@black:                     #000;
@gray:                      #CCC;
@white:                     #FFF;


// form
@form-group-margin-bottom:  15px;
@error:                     red;

@textarea-height:           auto;


// input group addons
@input-group-addon-before-bg:  @gray-lighter;
@input-group-addon-after-bg:   @white;

// input
@input-border-radius:          0;
@input-border-radius-base:     0;
@input-border-radius-small:    0;
@input-border-radius-large:    0;


// btns
@btns-padding:              5px 0px 5px 0px;

@btn-padding:               0;
@btn-margin:                0px 5px 0px 0px;
@btn-input-margin:          0;
@btn-input-padding:         0px 10px 0px 10px;

@btn-height:                25px;
@btn-line-height:           @btn-height;
@btn-font-size:             @font-size-base;

@btn-color:                 @white;
@btn-hover-color:           @btn-color;
@btn-bg:                    @orange;
@btn-hover-bg:              @btn-bg;

@btn-secondary-color:       @black;
@btn-secondary-hover-color: @btn-secondary-color;
@btn-secondary-bg:          @gray;
@btn-secondary-hover-bg:    @btn-secondary-bg;
@btn-secondary-padding:     0 0 0 25px;

@btn-link-color:            @orange;
@btn-link-hover-color:      @btn-link-color;
@btn-link-bg:               @white;
@btn-link-hover-bg:         @btn-link-bg;


// radio, checkbox picker
@picker-line-height:                    22px;
@picker-font-size:                      @font-size-base;
@picker-margin:                         0; //5px 0;

@picker-label-color:                    @text-color; //#555;
@picker-disabled-label-hover-color:     #888;
@picker-disabled-handle-hover-color:    #ccc;

@picker-label-padding:                  0;  // reset bootstrap padding-left: 20px;

@picker-handle-width:                   20px;
@picker-handle-height:                  20px;
@picker-handle-margin:                  0 5px 0 0;
@picker-handle-border:                  0; //1px solid #ccc;
@picker-handle-border-color:            @input-border; //1px solid #ccc;
@picker-handle-border-radius:           0; //8px;

@picker-flag-focus-bg:                  #ddd;
@picker-flag-hover-bg:                  #ddd;
@picker-flag-disabled-hover-bg:         #fff;

@picker-focus-handle-border-color:      @picker-handle-border-color;
@picker-focus-label-color:              @picker-label-color;

@picker-toggle-handle-border-radius:    @picker-handle-border-radius;
@picker-toggle-handle-width:            100%;
@picker-toggle-handle-height:           20px;
@picker-toggle-padding:                 20px 0 0;
@picker-toggle-flag-height:             100%;
@picker-toggle-flag-width:              50%;
@picker-toggle-flag-left:               50%;
@picker-toggle-flag-border-radius:      2px;
@picker-toggle-flag-margin:             0px;
@picker-toggle-flag-bg:                 #fff;
@picker-toggle-flag-checked-bg:         @brand-primary;
@picker-toggle-label-font-size:         @picker-font-size;
@picker-toggle-label-color:             #999;
@picker-toggle-label-on-color:          @picker-toggle-label-color;
@picker-toggle-label-off-color:         #333;
@picker-toggle-label-checked-on-color:  #333;
@picker-toggle-label-checked-off-color: #999;

@picker-radio-handle-margin:            @picker-handle-margin;
@picker-radio-handle-border:            0;
@picker-radio-handle-border-radius:     0;
@picker-radio-flag-height:              18px;
@picker-radio-flag-width:               18px;
@picker-radio-flag-border:              1px solid @input-border;
@picker-radio-flag-checked-border:      1px solid @brand-primary;
@picker-radio-flag-border-radius:       18px;
@picker-radio-flag-margin:              0;
@picker-radio-flag-bg:                  #fff;
@picker-radio-flag-focus-bg:            @brand-primary;
@picker-radio-flag-hover-bg:            @brand-primary;
@picker-radio-flag-checked-bg:          @brand-primary;
@picker-radio-flag-disabled-hover-bg:   #fff;

@picker-checkbox-handle-margin:         @picker-handle-margin;
@picker-checkbox-handle-border:         1px solid @input-border;
@picker-checkbox-handle-border-radius:  @picker-handle-border-radius;
@picker-checkbox-flag-height:           100%;
@picker-checkbox-flag-width:            100%;
@picker-checkbox-flag-border:           0;
@picker-checkbox-flag-border-radius:    0;
@picker-checkbox-flag-margin:           0;
@picker-checkbox-flag-bg:               #fff;

// make sure this image is available in your img folder or adjust this path
// and make sure the zrt-replace can rewrite this reference
@picker-checkbox-icon:                  '../img/j01FormPicker.png';


// select picker widget
@bootstrap-select-results-bg:           #f5f5f5;
@bootstrap-select-notify-bg:            #f5f5f5;
@bootstrap-select-notify-border:        1px solid #e3e3e3;

@color-red-error:                       rgb(185, 74, 72);
@color-grey-arrow:                      rgba(204, 204, 204, 0.2);
@width-default:                         220px; // 3 960px-grid columns
@zindex-select-dropdown:                1035; // must be lower than a modal background (1040) but higher than the fixed navbar (1030)

