// j01.form.forms.less
/*---[ addon ]----------------------------------------------------------------*/
// input-group-addon non border if addon get used
.input-group.input-group-before {
    .form-control {
        border-left: 0;
    }
    .input-group-addon:first-child {
        background-color: @input-group-addon-before-bg;
    }
}
.input-group.input-group-after {
    .form-control {
        border-right: 0;
    }
    .input-group-addon:last-child {
        background-color: @input-group-addon-after-bg;
    }
}


/*---[ errors ]---------------------------------------------------------------*/
// custom widget error representation
.widget-error {
    // absolute positioning
    position: relative;
    // icons don't overlap text
    .form-control {
        -right: (@input-height-base * 1.25);
    }
    .widget-error(@state-danger-text; @state-danger-text; @state-danger-bg);
}


/*---[ display mode ]---------------------------------------------------------*/
// display mode (given from default widget display layout template)
.widget-display {
    .form-control {
        color: @text-color;
        background-color: transparent;
        border: 0;
    }
}


/*---[ radio, checkbox widget]------------------------------------------------*/
// fix bootstrap checkbox and radio label/input space
.radio,
.checkbox {
    // adjust space between label -> checkbox and radio input
    margin-top: 0;
}
.radio input[type="radio"],
.radio-inline input[type="radio"],
.checkbox input[type="checkbox"],
.checkbox-inline input[type="checkbox"] {
  margin-top: 1px \9;
}

.radio + .radio,
.checkbox + .checkbox {
    // Move up sibling radios or checkboxes for tighter spacing
    margin-top: -5px;
}

/*---[ multi widget]----------------------------------------------------------*/
.multi-control-widget {
    .clearfix();
    padding-bottom: 10px;
    .multi-control-checkbox {
        float: left;
    }
    .multi-control-input {
        margin-left: 25px;
    }
}
