/* zrt-replace: "../img" tal"string:${context/++resource++img}" */
.picker-element {
  opacity: 0;
  position: absolute;
  transition: none;
  z-index: -1;
}
.no-touch .picker-element {
  left: -99999px;
}
.radio-inline-picker-widget .picker,
.checkbox-inline-picker-widget .picker {
  display: inline-block;
  padding: 0 20px 0 0;
}
.radio-inline-picker-widget .picker label,
.checkbox-inline-picker-widget .picker label {
  display: block;
}
.single-radio-widget .radio,
.single-checkbox-widget .radio,
.single-radio-picker-widget .radio,
.single-checkbox-picker-widget .radio,
.single-radio-widget .checkbox,
.single-checkbox-widget .checkbox,
.single-radio-picker-widget .checkbox,
.single-checkbox-picker-widget .checkbox {
  margin-top: 0;
}
.picker {
  cursor: pointer;
  margin: 0;
  overflow: hidden;
}
.picker .picker-label {
  color: #333333;
  cursor: pointer;
  display: block;
  float: left;
  font-size: 14px;
  line-height: 22px;
  user-select: none;
  padding: 0;
}
.picker .picker-handle {
  border: 0;
  display: block;
  float: left;
  height: 20px;
  margin: 0 5px 0 0;
  width: 20px;
}
.no-touch .picker:hover .picker-label {
  color: #333333;
}
.no-touch .picker:hover .picker-handle {
  border-color: #cccccc;
}
.picker.focus .picker-label {
  color: #333333;
}
.picker.focus .picker-handle {
  border-color: #cccccc;
}
.picker.picker-radio .picker-handle {
  border: 0;
  border-radius: 0;
  margin: 0 5px 0 0;
}
.picker.picker-radio .picker-flag {
  border: 1px solid #cccccc;
  border-radius: 18px;
  background: #ffffff;
  display: block;
  height: 18px;
  margin: 0;
  width: 18px;
}
.picker.picker-radio.focus .picker-flag {
  background: #337ab7;
}
.picker.picker-radio.checked .picker-flag {
  border: 1px solid #337ab7;
  background: #337ab7;
}
.no-touch .picker.picker-radio:hover .picker-flag {
  background: #337ab7;
}
.no-touch .picker.picker-radio.disabled:hover .picker-flag {
  background: #ffffff;
}
.picker.picker-checkbox .picker-handle {
  border: 1px solid #cccccc;
  border-radius: 0;
  margin: 0 5px 0 0;
}
.picker.picker-checkbox .picker-flag {
  border: 0;
  border-radius: 0;
  background: #ffffff;
  display: block;
  height: 100%;
  margin: 0;
  width: 100%;
}
.picker.picker-checkbox.checked .picker-flag {
  background: #ffffff url('../img/j01FormPicker.png') no-repeat center;
}
.picker.picker-toggle {
  padding: 20px 0 0;
  position: relative;
}
.picker.picker-toggle .picker-toggle-label {
  color: #999999;
  font-size: 14px;
  position: absolute;
  text-transform: uppercase;
  top: 0;
}
.picker.picker-toggle .picker-toggle-label.on {
  color: #999999;
  left: 0;
}
.picker.picker-toggle .picker-toggle-label.off {
  color: #333333;
  right: 0;
}
.picker.picker-toggle .picker-label {
  display: none;
}
.picker.picker-toggle .picker-handle {
  border-radius: 0;
  height: 20px;
  position: relative;
  width: 100%;
}
.picker.picker-toggle .picker-flag {
  background: #ffffff;
  border-radius: 0;
  display: block;
  height: 100%;
  left: 50%;
  margin: 0px;
  position: absolute;
  top: 0;
  width: 50%;
  transition: left 0.1s linear;
}
.picker.picker-toggle.checked .picker-toggle-label.on {
  color: #333333;
}
.picker.picker-toggle.checked .picker-toggle-label.off {
  color: #999999;
}
.picker.picker-toggle.checked .picker-flag {
  background: #337ab7;
  left: 0;
}
.picker.disabled {
  cursor: default;
  opacity: 0.5;
}
.picker.disabled .picker-label,
.picker.disabled .picker-handle {
  cursor: default;
}
.no-touch .picker.disabled:hover .picker-label {
  color: #888888;
}
.no-touch .picker.disabled:hover .picker-handle {
  border-color: #cccccc;
}
