// j01.form.select.less
/* zrt-replace: "../img" tal"string:${context/++resource++img}" */

// variables
@import "b3/variables.less";
@import "b3/mixins.less";
@import "source/variables.less";
@import "source/mixins.less";
@import "source/j01.form.select.less";
